@@ -7,7 +7,7 @@ def pre(hub, ctx: ContractedContext):
     """
     func_ctx = ctx.get_argument("ctx")
     if "endpoint_url" not in func_ctx.acct:
-        func_ctx.acct.endpoint_url = hub.exec.gcp.DEFAULT_ENDPOINT_URL
+        func_ctx.acct.endpoint_url = hub.exec.gcp_api.client.DEFAULT_ENDPOINT_URL
 
 
 async def _ret(status: bool, ret=None, comment: str = ""):
