@@ -352,7 +352,7 @@ async def present(
             ),
             body=resource_body,
             crypto_key_id=crypto_key_id,
-            skip_initial_version_creation=True,
+            skip_initial_version_creation=False,
         )
         if not create_ret["result"]:
             result["result"] = False
@@ -525,3 +525,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
                         p.append({"crypto_key_id": els["crypto_key_id"]})
 
     return result
+
+
+def is_pending(hub, ret: dict, state: str = None, **pending_kwargs) -> bool:
+    return hub.tool.gcp.utils.is_pending(ret=ret, state=state, **pending_kwargs)
