@@ -718,3 +718,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
                                 )
 
     return result
+
+
+def is_pending(hub, ret: dict, state: str = None, **pending_kwargs) -> bool:
+    return hub.tool.gcp.utils.is_pending(ret=ret, state=state, **pending_kwargs)
