@@ -26,7 +26,7 @@ async def present(
     expire_event_time: str = None,
     job_state: str = None,
     public_key: str = None,
-    attestation=make_dataclass(
+    attestation: make_dataclass(
         "KeyOperationAttestation",
         [
             ("format", str, field(default=None)),
@@ -52,7 +52,7 @@ async def present(
                 field(default=None),
             ),
         ],
-    ),
+    ) = None,
     resource_id: str = None,
 ) -> Dict[str, Any]:
     """Create a new `ImportJob`_ within a `KeyRing`_.
