@@ -6,8 +6,6 @@ from typing import Any
 from typing import Dict
 from typing import List
 
-from idem_gcp.tool.gcp.utils import get_project_from_account
-
 __contracts__ = ["resource"]
 
 
@@ -337,54 +335,13 @@ async def present(
         "comment": [],
     }
 
-    project = get_project_from_account(ctx, project)
+    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
-    # Get the resource_id from ESM
-    if not resource_id:
-        resource_id = (ctx.old_state or {}).get(
-            "resource_id"
-        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "compute.disk", {**locals(), "disk": name}
+    if ctx.get("wrapper_result"):
+        result["old_state"] = copy.deepcopy(
+            copy.copy(ctx.get("wrapper_result").get("old_state", None))
         )
 
-    if ctx.get("rerun_data"):
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.disk"
-        )
-
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    if resource_id:
-        old_get_ret = await hub.exec.gcp.compute.disk.get(
-            ctx, name=name, resource_id=resource_id
-        )
-
-        if not old_get_ret["result"]:
-            # error other than non-existing resource
-            result["result"] = False
-            result["comment"] += old_get_ret["comment"]
-            return result
-        if old_get_ret["ret"]:
-            # copy.copy(old_get_ret['ret']) is needed to convert any objects of type NamespaceDict to dict
-            # in old_get_ret['ret']. This is done so that comparisons with the plan_state which has
-            # objects of type dict works properly
-            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
-            zone = hub.tool.gcp.resource_prop_utils.parse_link_to_zone(
-                result["old_state"]["zone"]
-            )
-            result["old_state"]["zone"] = zone
-
-            # If rerun_data is set at this point this means that there has been a completed create or update operation
-            # so there is no need to run the code for create or update below again, and we stop here
-            if ctx.get("rerun_data"):
-                result["new_state"] = result["old_state"]
-                return result
-
     # to be autogenerated by pop-create based on insert/update props in properties.yaml
     resource_body = {
         "type": type,
@@ -420,6 +377,11 @@ async def present(
     plan_state = {k: v for (k, v) in plan_state.items() if v is not None}
     operation = None
     if result["old_state"]:
+        resource_id = result["old_state"].get("resource_id", None)
+        zone = hub.tool.gcp.resource_prop_utils.parse_link_to_zone(
+            result["old_state"]["zone"]
+        )
+        result["old_state"]["zone"] = zone
         # Resize
         size_gb_updated = False
         if size_gb is not None and str(result["old_state"]["size_gb"]) != str(size_gb):
@@ -437,7 +399,7 @@ async def present(
                     result["comment"] += update_ret["comment"]
                     return result
 
-                if "compute#operation" in update_ret["ret"].get("kind"):
+                if hub.tool.gcp.operation_utils.is_operation(update_ret["ret"]):
                     operation = update_ret["ret"]
                     operation_id = (
                         hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
@@ -449,7 +411,6 @@ async def present(
                     )
                     if not op_ret["result"]:
                         result["comment"] += op_ret["comment"]
-                        result["rerun_data"] = op_ret["rerun_data"]
                         return result
 
             size_gb_updated = True
@@ -480,7 +441,7 @@ async def present(
                     result["comment"] += update_ret["comment"]
                     return result
 
-                if "compute#operation" in update_ret["ret"].get("kind"):
+                if hub.tool.gcp.operation_utils.is_operation(update_ret["ret"]):
                     operation = update_ret["ret"]
                     operation_id = (
                         hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
@@ -492,7 +453,6 @@ async def present(
                     )
                     if not op_ret["result"]:
                         result["comment"] += op_ret["comment"]
-                        result["rerun_data"] = op_ret["rerun_data"]
                         return result
 
             labels_updated = True
@@ -559,7 +519,7 @@ async def present(
                             result["comment"] += remove_ret["comment"]
                             return result
 
-                        if "compute#operation" in remove_ret["ret"].get("kind"):
+                        if hub.tool.gcp.operation_utils.is_operation(remove_ret["ret"]):
                             operation = remove_ret["ret"]
                             operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
                                 operation.get("selfLink"), "compute.zone_operation"
@@ -571,7 +531,6 @@ async def present(
                             )
                             if not op_ret["result"]:
                                 result["comment"] += op_ret["comment"]
-                                result["rerun_data"] = op_ret["rerun_data"]
                                 return result
 
                     if (
@@ -589,7 +548,7 @@ async def present(
                             result["comment"] += add_ret["comment"]
                             return result
 
-                        if "compute#operation" in add_ret["ret"].get("kind"):
+                        if hub.tool.gcp.operation_utils.is_operation(add_ret["ret"]):
                             operation = add_ret["ret"]
                             operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
                                 operation.get("selfLink"), "compute.zone_operation"
@@ -601,7 +560,6 @@ async def present(
                             )
                             if not op_ret["result"]:
                                 result["comment"] += op_ret["comment"]
-                                result["rerun_data"] = op_ret["rerun_data"]
                                 return result
 
                 resource_policies_updated = True
@@ -619,10 +577,22 @@ async def present(
                         "gcp.compute.disk", name
                     )
                 )
+                result["new_state"] = {**result["old_state"], **plan_state}
+                result["new_state"]["resource_id"] = resource_id
             else:
+                get_ret = await hub.exec.gcp.compute.disk.get(
+                    ctx, name=name, resource_id=resource_id
+                )
+                if not get_ret["result"] and not get_ret["ret"]:
+                    result["result"] = False
+                    result["comment"] += get_ret["comment"]
+                    return result
+
+                result["new_state"] = get_ret["ret"]
                 result["comment"].append(
                     hub.tool.gcp.comment_utils.update_comment("gcp.compute.disk", name)
                 )
+                return result
         else:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.already_exists_comment(
@@ -653,37 +623,19 @@ async def present(
             )
             resource_id = create_ret["ret"].get("resource_id")
         if create_ret["ret"] is not None:
-            if "compute#operation" in create_ret["ret"].get("kind"):
+            if hub.tool.gcp.operation_utils.is_operation(create_ret["ret"]):
                 operation = create_ret["ret"]
 
     if operation:
         operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
             operation.get("selfLink"), "compute.zone_operation"
         )
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, operation_id, "compute.disk"
-        )
-
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    # Try getting the resource again
-    # TODO: Check if this can be removed because insert and update may also return the necessary data on success
-    get_ret = await hub.exec.gcp.compute.disk.get(
-        ctx, name=name, resource_id=resource_id
-    )
-
-    if not get_ret["result"] or not get_ret["ret"]:
-        result["result"] = False
-        result["comment"] += get_ret["comment"]
+        result["rerun_data"] = {
+            "operation_id": operation_id,
+            "old_state": result["old_state"],
+        }
         return result
 
-    result["new_state"] = get_ret["ret"]
-
     return result
 
 
@@ -738,7 +690,15 @@ async def absent(
         "comment": [],
     }
 
-    resource_id = resource_id or (ctx.old_state or {}).get("resource_id")
+    if not resource_id and not hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    ):
+        resource_id = (ctx.get("old_state") or {}).get(
+            "resource_id"
+        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
+            "compute.disk", {**locals(), "disk": name}
+        )
+
     if not resource_id:
         result["comment"].append(
             hub.tool.gcp.comment_utils.already_absent_comment("gcp.compute.disk", name)
@@ -775,7 +735,7 @@ async def absent(
             ctx, resource_id=resource_id
         )
         if delete_ret["ret"]:
-            if "compute#operation" in delete_ret["ret"].get("kind"):
+            if hub.tool.gcp.operation_utils.is_operation(delete_ret["ret"]):
                 result["result"] = False
                 result["comment"] += delete_ret["comment"]
                 result[
