@@ -11,7 +11,8 @@ from dataclasses import field
 from dataclasses import make_dataclass
 from typing import Dict, Any, List
 import copy
-from idem_gcp.tool.gcp.utils import get_project_from_account
+
+from idem_gcp.tool.gcp.state_operation_utils import StateOperations
 
 
 async def present(
@@ -1124,70 +1125,13 @@ async def present(
         "name": name,
         "comment": [],
     }
-    project = get_project_from_account(ctx, project)
+    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
-    if ctx.get("rerun_data"):
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data").get("operation_id"), "compute.instance"
+    if ctx.get("wrapper_result"):
+        result["old_state"] = copy.deepcopy(
+            copy.copy(ctx.get("wrapper_result").get("old_state", None))
         )
 
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = ctx.get("rerun_data")
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    get_resource_only_with_resource_id = hub.OPT.idem.get(
-        "get_resource_only_with_resource_id", False
-    )
-    if resource_id:
-        old_get_ret = await hub.exec.gcp.compute.instance.get(
-            ctx, resource_id=resource_id
-        )
-
-        if not old_get_ret["result"] or (
-            not old_get_ret["ret"] and get_resource_only_with_resource_id
-        ):
-            result["result"] = False
-            result["comment"] += old_get_ret["comment"]
-            return result
-
-        # long running operation has succeeded - both update and create
-        if ctx.get("rerun_data"):
-            result["new_state"] = old_get_ret["ret"]
-            result["old_state"] = ctx["rerun_data"]["old_state"]
-            if ctx["rerun_data"]["old_state"]:
-                result["comment"].append(
-                    hub.tool.gcp.comment_utils.update_comment(
-                        "gcp.compute.instance", name
-                    )
-                )
-            else:
-                result["comment"].append(
-                    hub.tool.gcp.comment_utils.create_comment(
-                        "gcp.compute.instance", name
-                    )
-                )
-            return result
-
-        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
-    elif not get_resource_only_with_resource_id:
-        resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "compute.instance", {**locals(), "instance": name}
-        )
-        old_get_ret = await hub.exec.gcp.compute.instance.get(
-            ctx, resource_id=resource_id
-        )
-
-        if not old_get_ret["result"]:
-            result["result"] = False
-            result["comment"] += old_get_ret["comment"]
-            return result
-
-        if old_get_ret["ret"]:
-            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
-
     # to be autogenerated by pop-create based on insert/update props in properties.yaml
     resource_body = {
         "service_accounts": service_accounts,
@@ -1225,6 +1169,7 @@ async def present(
     resource_body = {k: v for (k, v) in resource_body.items() if v is not None}
     operation = None
     if result["old_state"]:
+        resource_id = result["old_state"].get("resource_id", None)
         # copy.copy(old_get_ret['ret']) is needed to convert any objects of type NamespaceDict to dict
         # in old_get_ret['ret']. This is done so that comparisons with the resource_body which has
         # objects of type dict works properly
@@ -1251,6 +1196,11 @@ async def present(
                 (ctx, result["old_state"], network_interfaces),
                 True,
             ),
+            "status": (
+                hub.tool.gcp.compute.instance.update_status,
+                (ctx, resource_id, result["old_state"].get("status"), status),
+                True,
+            ),
             "shielded_instance_config": (
                 hub.tool.gcp.compute.instance.update_shielded_instance_config,
                 (ctx, shielded_instance_config, None, None, None, resource_id),
@@ -1268,28 +1218,19 @@ async def present(
                 ),
                 False,
             ),
-            "status": (
-                hub.tool.gcp.compute.instance.update_status,
-                (ctx, resource_id, result["old_state"].get("status"), status),
-                True,
-            ),
         }
 
-        old_properties_dict = {
-            k: result["old_state"].get(k) for k in patch_operations_dict.keys()
-        }
-        changed_properties_dict = {
-            k: hub.tool.gcp.utils.compare_states(
-                {k: old_properties_dict.get(k, [])},
-                {k: resource_body.get(k, [])},
-                "compute.instance",
-            )
-            for k, v in patch_operations_dict.items()
-        }
+        state_operations = StateOperations(
+            hub, "compute.instance", patch_operations_dict, result, resource_body
+        )
 
         changes = hub.tool.gcp.utils.compare_states(
             result["old_state"],
-            {"resource_id": resource_id, **resource_body, **old_properties_dict},
+            {
+                "resource_id": resource_id,
+                **resource_body,
+                **state_operations.old_properties_dict,
+            },
             "compute.instance",
         )
 
@@ -1311,7 +1252,7 @@ async def present(
                 result["new_state"] = copy.deepcopy(result["old_state"])
                 return result
 
-        if not changes and not any(changed_properties_dict.values()):
+        if not changes and not any(state_operations.changed_properties_dict.values()):
             result["result"] = True
             result["comment"].append(
                 hub.tool.gcp.comment_utils.up_to_date_comment(
@@ -1331,17 +1272,17 @@ async def present(
             result["new_state"]["resource_id"] = resource_id
             return result
 
-        for k, op in patch_operations_dict.items():
-            if changed_properties_dict[k]:
-                ret = await op[0](*op[1])
+        state_operations_ret = await state_operations.run_operations()
 
-                if not ret["result"]:
-                    result["comment"] += ret["comment"]
-                    result["result"] = False
-                    return result
+        if not state_operations_ret["result"]:
+            result["comment"] += state_operations_ret["comment"]
+            result["result"] = False
+            return result
+        elif "new_state" in state_operations_ret:
+            result["new_state"] = state_operations_ret["new_state"]
 
         if changes:
-            if any(changed_properties_dict.values()):
+            if any(state_operations.changed_properties_dict.values()):
                 get_ret = await hub.exec.gcp.compute.instance.get(
                     ctx, resource_id=resource_id
                 )
@@ -1358,10 +1299,7 @@ async def present(
                     "label_fingerprint"
                 )
 
-            # put the old value of required properties in the resource body
-            for k, v in patch_operations_dict.items():
-                if v[2] and not resource_body.get(k):
-                    resource_body[k] = old_properties_dict[k]
+            state_operations.pre_process_resource_body(resource_body)
 
             update_ret = await hub.exec.gcp_api.client.compute.instance.update(
                 hub,
@@ -1378,10 +1316,10 @@ async def present(
                 result["comment"] += update_ret["comment"]
                 return result
 
-            if "compute#operation" in update_ret["ret"].get("kind", ""):
+            if hub.tool.gcp.operation_utils.is_operation(update_ret["ret"]):
                 operation = update_ret["ret"]
 
-        if not changes and any(changed_properties_dict.values()):
+        if not changes and any(state_operations.changed_properties_dict.values()):
             get_ret = await hub.exec.gcp.compute.instance.get(
                 ctx, resource_id=resource_id
             )
@@ -1436,7 +1374,7 @@ async def present(
                 result["comment"] += create_ret["comment"]
             return result
 
-        if "compute#operation" in create_ret["ret"].get("kind", ""):
+        if hub.tool.gcp.operation_utils.is_operation(create_ret["ret"]):
             operation = create_ret["ret"]
 
     if operation:
@@ -1546,7 +1484,7 @@ async def absent(
         delete_ret = await hub.exec.gcp_api.client.compute.instance.delete(
             ctx, resource_id=resource_id, request_id=request_id
         )
-        if "compute#operation" in delete_ret.get("ret", {}).get("kind"):
+        if hub.tool.gcp.operation_utils.is_operation(delete_ret.get("ret")):
             result["result"] = False
             result["comment"] += delete_ret["comment"]
             result[
