@@ -6,7 +6,6 @@ from typing import Any
 from typing import Dict
 from typing import List
 
-from idem_gcp.tool.gcp.utils import get_project_from_account
 
 __contracts__ = ["resource"]
 
@@ -23,8 +22,20 @@ async def present(
         make_dataclass(
             "SourceDiskEncryptionKey",
             [
-                ("sourceDisk", str, field(default=None)),
-                ("diskEncryptionKey", {}, field(default=None)),
+                ("source_disk", str, field(default=None)),
+                (
+                    "disk_encryption_key",
+                    make_dataclass(
+                        "CustomerEncryptionKey",
+                        [
+                            ("kms_key_service_account", str, field(default=None)),
+                            ("rsa_encrypted_key", str, field(default=None)),
+                            ("kms_key_name", str, field(default=None)),
+                            ("raw_key", str, field(default=None)),
+                        ],
+                    ),
+                    field(default=None),
+                ),
             ],
         )
     ] = None,
@@ -34,10 +45,10 @@ async def present(
             "SavedDisk",
             [
                 ("kind", str, field(default="compute#savedDisk")),
-                ("storageBytesStatus", str, field(default=None)),
+                ("storage_bytes_status", str, field(default=None)),
                 ("architecture", str, field(default=None)),
-                ("storageBytes", str, field(default=None)),
-                ("sourceDisk", str, field(default=None)),
+                ("storage_bytes", str, field(default=None)),
+                ("source_disk", str, field(default=None)),
             ],
         )
     ] = None,
@@ -45,10 +56,10 @@ async def present(
     machine_image_encryption_key: make_dataclass(
         "CustomerEncryptionKey",
         [
-            ("kmsKeyServiceAccount", str, field(default=None)),
-            ("rsaEncryptedKey", str, field(default=None)),
-            ("rawKey", str, field(default=None)),
-            ("kmsKeyName", str, field(default=None)),
+            ("kms_key_service_account", str, field(default=None)),
+            ("rsa_encrypted_key", str, field(default=None)),
+            ("raw_key", str, field(default=None)),
+            ("kms_key_name", str, field(default=None)),
         ],
     ) = None,
 ) -> Dict[str, Any]:
@@ -73,9 +84,12 @@ async def present(
 
         source_disk_encryption_keys(list[Dict[str, Any]], Optional):
             [Input Only] The customer-supplied encryption key of the disks attached to the source instance. Required if the source disk is protected by a customer-supplied encryption key. Defaults to None.
-            * properties (Dict[str, Dict[str, Any]], optional): None
-                * sourceDisk (str, optional): URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk
-                * diskEncryptionKey ({}, optional): The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
+            * source_disk(str, Optional): URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/disks/disk
+            * disk_encryption_key(Dict[str, Any], Optional): The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
+                * kms_key_service_account(str, Optional): The service account being used for the encryption request for the given KMS key. If absent, the Compute Engine default service account is used. For example: "kmsKeyServiceAccount": "name@project_id.iam.gserviceaccount.com/
+                * rsa_encrypted_key(str, Optional): Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey. For example: "rsaEncryptedKey": "ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH z0mBibXUInrC/jEk014kCK/NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFoD D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEMMoNUXMCZEIpg9Vtp9x2oe==" The key must meet the following requirements before you can provide it to Compute Engine: 1. The key is wrapped using a RSA public key certificate provided by Google. 2. After being wrapped, the key must be encoded in RFC 4648 base64 encoding. Gets the RSA public key certificate provided by Google at: https://cloud-certs.storage.googleapis.com/google-cloud-csek-ingress.pem
+                * kms_key_name(str, Optional): The name of the encryption key that is stored in Google Cloud KMS. For example: "kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key
+                * raw_key(str, Optional): Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey. For example: "rawKey": "SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0="
 
         description(str, Optional):
             An optional description of this resource. Provide this property when you create the resource. Defaults to None.
@@ -92,8 +106,12 @@ async def present(
         guest_flush(bool, Optional):
             [Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process. Defaults to None.
 
-        machine_image_encryption_key({}, Optional):
+        machine_image_encryption_key(Dict[str, Any], Optional):
             Encrypts the machine image using a customer-supplied encryption key. After you encrypt a machine image using a customer-supplied key, you must provide the same key if you use the machine image later. For example, you must provide the encryption key when you create an instance from the encrypted machine image in a future request. Customer-supplied encryption keys do not protect access to metadata of the machine image. If you do not provide an encryption key when creating the machine image, then the machine image will be encrypted using an automatically generated key and you do not need to provide a key to use the machine image later. Defaults to None.
+            * kms_key_service_account(str, Optional): The service account being used for the encryption request for the given KMS key. If absent, the Compute Engine default service account is used. For example: "kmsKeyServiceAccount": "name@project_id.iam.gserviceaccount.com/
+            * rsa_encrypted_key(str, Optional): Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey. For example: "rsaEncryptedKey": "ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH z0mBibXUInrC/jEk014kCK/NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFoD D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEMMoNUXMCZEIpg9Vtp9x2oe==" The key must meet the following requirements before you can provide it to Compute Engine: 1. The key is wrapped using a RSA public key certificate provided by Google. 2. After being wrapped, the key must be encoded in RFC 4648 base64 encoding. Gets the RSA public key certificate provided by Google at: https://cloud-certs.storage.googleapis.com/google-cloud-csek-ingress.pem
+            * kms_key_name(str, Optional): The name of the encryption key that is stored in Google Cloud KMS. For example: "kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key
+            * raw_key(str, Optional): Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource. You can provide either the rawKey or the rsaEncryptedKey. For example: "rawKey": "SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0="
 
     Returns:
         Dict[str, Any]
@@ -101,10 +119,10 @@ async def present(
     Examples:
         .. code-block:: sls
 
-            example_resource_name:
-                gcp.compute.machine_image.present:
-                  - project: project-name
-                  - source_instance: https://www.googleapis.com/compute/v1/projects/project-name/zones/zone-name/instances/instance-name
+        example_resource_name:
+            gcp.compute.machine_image.present:
+              - project: project-name
+              - source_instance: https://www.googleapis.com/compute/v1/projects/project-name/zones/zone-name/instances/instance-name
     """
     result = {
         "result": True,
@@ -114,7 +132,7 @@ async def present(
         "comment": [],
     }
 
-    project = get_project_from_account(ctx, project)
+    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
     # Get the resource_id from ESM
     if not resource_id:
@@ -229,7 +247,7 @@ async def present(
         )
         result["old_state"] = {}
         resource_id = create_ret["ret"].get("resource_id")
-        if "compute#operation" in create_ret["ret"].get("kind"):
+        if hub.tool.gcp.operation_utils.is_operation(create_ret["ret"]):
             operation = create_ret["ret"]
 
     if operation:
@@ -268,6 +286,7 @@ async def absent(
     hub,
     ctx,
     name: str,
+    project: str = None,
     resource_id: str = None,
     request_id: str = None,
 ) -> Dict[str, Any]:
@@ -277,6 +296,9 @@ async def absent(
         name(str):
             An Idem name of the resource.
 
+        project(str, Optional):
+            Project ID for this request.
+
         resource_id(str, Optional):
             An identifier of the resource in the provider. Defaults to None.
 
@@ -303,8 +325,16 @@ async def absent(
         "result": True,
     }
 
-    if not resource_id:
-        resource_id = (ctx.get("old_state") or {}).get("resource_id")
+    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
+
+    if not resource_id and not hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    ):
+        resource_id = (ctx.get("old_state") or {}).get(
+            "resource_id"
+        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
+            "compute.machine_image", {**locals(), "machineImage": name}
+        )
 
     if ctx.test:
         result["comment"].append(
@@ -320,7 +350,7 @@ async def absent(
             ctx, resource_id=resource_id
         )
         if delete_ret["ret"]:
-            if "compute#operation" in delete_ret["ret"].get("kind"):
+            if hub.tool.gcp.operation_utils.is_operation(delete_ret["ret"]):
                 result["result"] = False
                 result["comment"] += delete_ret["comment"]
                 result[
