@@ -6,8 +6,6 @@ from typing import Any
 from typing import Dict
 from typing import List
 
-from idem_gcp.tool.gcp.utils import get_project_from_account
-
 __contracts__ = ["resource"]
 
 
@@ -141,17 +139,7 @@ async def present(
         "comment": [],
     }
 
-    project = get_project_from_account(ctx, project)
-
-    # Get the resource_id from ESM
-    if not resource_id:
-        resource_id = (ctx.get("old_state") or {}).get(
-            "resource_id"
-        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "compute.network", {**locals(), "network": name}
-        )
-
-    old = None
+    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
     if ctx.get("rerun_data"):
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
@@ -166,27 +154,32 @@ async def present(
         resource_id = handle_operation_ret["resource_id"]
 
     if resource_id:
-        old_get_ret = await hub.exec.gcp_api.client.compute.network.get(
-            ctx, name=name, resource_id=resource_id
+        old_get_ret = await hub.exec.gcp.compute.network.get(
+            ctx, resource_id=resource_id
         )
 
+        if not old_get_ret["result"] or not old_get_ret["ret"]:
+            result["result"] = False
+            result["comment"] += old_get_ret["comment"]
+            return result
+
+        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+    elif not hub.OPT.idem.get("get_resource_only_with_resource_id", False):
+        resource_id = (ctx.get("old_state") or {}).get(
+            "resource_id"
+        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
+            "compute.network", {**locals(), "network": name}
+        )
+        old_get_ret = await hub.exec.gcp.compute.network.get(
+            ctx, resource_id=resource_id
+        )
         if not old_get_ret["result"]:
-            # error other than non-existing resource
             result["result"] = False
             result["comment"] += old_get_ret["comment"]
             return result
 
         if old_get_ret["ret"]:
-            # resource already exists
-
-            # copy.copy(old_get_ret['ret']) is needed to convert any objects of type NamespaceDict to dict
-            # in old_get_ret['ret']. This is done so that comparisons with the plan_state which has
-            # objects of type dict works properly
-            old = copy.deepcopy(copy.copy(old_get_ret["ret"]))
-            result["old_state"] = old
-
-        # do not return here even after fetching network post operation return,
-        # as there are further update operations below which might need to run
+            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
 
     request_body = {
         "name": name,
@@ -203,22 +196,26 @@ async def present(
 
     request_body = {k: v for (k, v) in request_body.items() if v is not None}
     operation = None
-    if old:
+    if result["old_state"]:
         new_state_for_whole_resource_comparison = {
             "resource_id": resource_id,
             **request_body,
         }
-        if hasattr(old, "peerings"):
-            new_state_for_whole_resource_comparison["peerings"] = old.get("peerings")
+        if hasattr(result["old_state"], "peerings"):
+            new_state_for_whole_resource_comparison["peerings"] = result[
+                "old_state"
+            ].get("peerings")
         else:
             new_state_for_whole_resource_comparison.pop("peerings", None)
 
         changes = hub.tool.gcp.utils.compare_states(
-            old, new_state_for_whole_resource_comparison, "compute.network"
+            result["old_state"],
+            new_state_for_whole_resource_comparison,
+            "compute.network",
         )
         are_peerings_changed = (
             not hub.tool.gcp.state_comparison_utils.are_lists_identical(
-                old.get("peerings"), peerings
+                result["old_state"].get("peerings"), peerings
             )
         )
 
@@ -244,7 +241,7 @@ async def present(
 
         if are_peerings_changed:
             update_peerings_ret = await hub.tool.gcp.compute.network.update_peerings(
-                ctx, resource_id, old.get("peerings"), peerings
+                ctx, resource_id, result["old_state"].get("peerings"), peerings
             )
             if not update_peerings_ret["result"]:
                 result["result"] = False
@@ -273,7 +270,7 @@ async def present(
                 result["comment"].append(patch_ret["comment"])
                 return result
             if patch_ret["ret"] is not None:
-                if "compute#operation" in patch_ret["ret"].get("kind"):
+                if hub.tool.gcp.operation_utils.is_operation(patch_ret["ret"]):
                     operation = patch_ret["ret"]
 
         result["comment"].append(
@@ -301,7 +298,7 @@ async def present(
 
         result["old_state"] = {}
         resource_id = create_ret["ret"].get("resource_id")
-        if "compute#operation" in create_ret["ret"].get("kind"):
+        if hub.tool.gcp.operation_utils.is_operation(create_ret["ret"]):
             operation = create_ret["ret"]
 
     if operation:
@@ -406,7 +403,7 @@ async def absent(
             ctx, resource_id=resource_id
         )
         if delete_ret["ret"]:
-            if "compute#operation" in delete_ret["ret"].get("kind"):
+            if hub.tool.gcp.operation_utils.is_operation(delete_ret["ret"]):
                 result["result"] = False
                 result["comment"] += delete_ret["comment"]
                 result[
