@@ -303,7 +303,7 @@ async def present(
     }
 
     # TODO uncomment below line, when implementation is added
-    # project = get_project_from_account(ctx, project)
+    # project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
     result["comment"].append(
         "No-op: There is no create/update function for gcp.compute.resource_policy"
@@ -375,7 +375,7 @@ async def absent(
             ctx, resource_id=resource_id
         )
         if delete_ret["ret"]:
-            if "compute#operation" in delete_ret["ret"].get("kind"):
+            if hub.tool.gcp.operation_utils.is_operation(delete_ret["ret"]):
                 result["result"] = False
                 result["comment"] += delete_ret["comment"]
                 result[
