@@ -8,8 +8,6 @@ from typing import List
 
 __contracts__ = ["resource"]
 
-from idem_gcp.tool.gcp.utils import get_project_from_account
-
 
 async def present(
     hub,
@@ -171,7 +169,7 @@ async def present(
         "comment": [],
     }
 
-    project = get_project_from_account(ctx, project)
+    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
     # Handle operation(s) in progress, if any
     if ctx.get("rerun_data"):
@@ -258,7 +256,7 @@ async def present(
             hub.tool.gcp.comment_utils.update_comment("gcp.compute.subnetwork", name)
         )
 
-        if "compute#operation" in update["ret"].get("kind"):
+        if hub.tool.gcp.operation_utils.is_operation(update["ret"]):
             operation = update["ret"]
 
     else:
@@ -289,7 +287,7 @@ async def present(
             hub.tool.gcp.comment_utils.create_comment("gcp.compute.subnetwork", name)
         )
 
-        if "compute#operation" in create["ret"].get("kind"):
+        if hub.tool.gcp.operation_utils.is_operation(create["ret"]):
             operation = create["ret"]
 
     if operation:
@@ -338,7 +336,7 @@ async def present(
             result["comment"] += ret["comment"]
             return result
 
-        if "compute#operation" in ret["ret"].get("kind"):
+        if hub.tool.gcp.operation_utils.is_operation(ret["ret"]):
             operation = ret["ret"]
 
             operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
@@ -373,7 +371,7 @@ async def present(
             result["comment"] += ret["comment"]
             return result
 
-        if "compute#operation" in ret["ret"].get("kind"):
+        if hub.tool.gcp.operation_utils.is_operation(ret["ret"]):
             operation = ret["ret"]
 
             operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
@@ -501,7 +499,7 @@ async def absent(
                 ctx, resource_id=resource_id
             )
             if delete["ret"]:
-                if "compute#operation" in delete["ret"].get("kind"):
+                if hub.tool.gcp.operation_utils.is_operation(delete["ret"]):
                     result["result"] = False
                     result["comment"] += delete["comment"]
                     result[
