@@ -54,6 +54,14 @@ def get_empty_comment(hub, resource_type: str, name: str) -> str:
     return f"Get {resource_type} '{name}' result is empty"
 
 
+def resource_not_found_comment(hub, resource_type: str, resource_id: str) -> str:
+    return f"Could not find {resource_type} with resource_id={resource_id}"
+
+
+def resource_discovered_comment(hub, resource_type: str, resource_id: str) -> str:
+    return f"Discovered existing {resource_type} with resource_id={resource_id}"
+
+
 def list_empty_comment(hub, resource_type: str, name: str) -> str:
     return f"List {resource_type} '{name}' result is empty"
 
@@ -73,10 +81,14 @@ def non_updatable_properties_comment(
 
 
 def no_resource_update_comment(hub, resource_type: str, resource_id: str) -> str:
-    return f"Update operation for resource type {resource_type} is not supported for {resource_id}."
+    return f"Update operation for resource type {resource_type} is not supported for {resource_id}"
 
 
 def ill_formed_resource_id_comment(
     hub, resource_type: str, resource_id: str, reason: str
 ) -> str:
     return f"Ill-formed {resource_type} resource ID '{resource_id}': {reason}"
+
+
+def resource_not_found_comment(hub, resource_type: str, resource_id: str) -> str:
+    return f"Resource {resource_type} with resource ID '{resource_id}' not found"
