@@ -126,3 +126,85 @@ async def update_network_interfaces(
 
     result["result"] = True
     return result
+
+
+async def update_shielded_instance_config(
+    hub,
+    ctx,
+    shielded_instance_config: Dict[str, bool],
+    project: str = None,
+    zone: str = None,
+    instance: str = None,
+    resource_id: str = None,
+) -> Dict[str, Any]:
+    return await hub.exec.gcp.compute.instance.update_shielded_instance_config(
+        ctx,
+        shielded_instance_config["enable_secure_boot"],
+        shielded_instance_config["enable_vtpm"],
+        shielded_instance_config["enable_integrity_monitoring"],
+        project,
+        zone,
+        instance,
+        resource_id,
+    )
+
+
+async def update_shielded_instance_integrity_policy(
+    hub,
+    ctx,
+    shielded_instance_integrity_policy: Dict[str, bool],
+    project: str = None,
+    zone: str = None,
+    instance: str = None,
+    resource_id: str = None,
+) -> Dict[str, Any]:
+    return await hub.exec.gcp.compute.instance.set_shielded_instance_integrity_policy(
+        ctx,
+        shielded_instance_integrity_policy["update_auto_learn_policy"],
+        project,
+        zone,
+        instance,
+        resource_id,
+    )
+
+
+async def update_status(
+    hub,
+    ctx,
+    resource_id: str,
+    current_status: str,
+    desired_status: str,
+) -> Dict[str, Any]:
+
+    result = {"result": False, "comment": []}
+
+    states = ["RUNNING", "SUSPENDED", "TERMINATED"]
+    if not desired_status in states:
+        result["comment"].append(
+            f"Incorrect instance status in the request: {desired_status}, must be one of: {states}"
+        )
+        return result
+
+    # See https://cloud.google.com/compute/docs/instances/instance-life-cycle for instance's state transition diagram
+
+    ret = None
+    if current_status in ["PROVISIONING", "STAGING", "RUNNING", "REPAIRING"]:
+        if desired_status == "TERMINATED":
+            ret = await hub.exec.gcp.compute.instance.stop(ctx, resource_id=resource_id)
+        elif desired_status == "SUSPENDED":
+            ret = await hub.exec.gcp.compute.instance.suspend(
+                ctx, resource_id=resource_id
+            )
+    elif current_status in ["STOPPING", "TERMINATED"] and desired_status == "RUNNING":
+        ret = await hub.exec.gcp.compute.instance.start(ctx, resource_id=resource_id)
+    elif current_status in ["SUSPENDING", "SUSPENDED"] and desired_status == "RUNNING":
+        ret = await hub.exec.gcp.compute.instance.resume(ctx, resource_id=resource_id)
+    else:
+        result["comment"].append(
+            f"Incorrect instance status transition: {current_status} => {desired_status}"
+        )
+        return result
+
+    result["result"] = ret["result"]
+    result["comment"] += ret["comment"]
+    return result
