@@ -5,7 +5,7 @@ async def should_operate(hub, execution_context: ExecutionContext) -> bool:
     return (
         execution_context.response is not None
         and execution_context.response.get("ret") is not None
-        and "compute#operation" in execution_context.response["ret"].get("kind", "")
+        and hub.tool.gcp.operation_utils.is_operation(execution_context.response["ret"])
     )
 
 
