@@ -12,7 +12,7 @@ Management via POP ReverseSub.
 The basic operating model is building Subs as needed to match the nature of a
 call to an exec. For example, a call like:
 
-    gcp.compute.instances.get(ctx, ...)
+    gcp.compute.instance.get(ctx, ...)
 
 Those are ultimately implemented by calls to the _GCPApi class runnable.
 
@@ -42,6 +42,7 @@ def __virtual__(hub):
 
 
 def __init__(hub):
+    # hub.pop.sub.load_subdirs(hub.tool.gcp, recurse=True)
     hub.pop.sub.add(dyne_name="metadata")
     hub.pop.sub.load_subdirs(hub.metadata, recurse=True)
     """
