@@ -1,4 +1,4 @@
-import time
+import asyncio
 from typing import Any
 from typing import Dict
 
@@ -78,6 +78,8 @@ async def handle_operation(
 
 
 async def wait_for_operation(hub, ctx, operation, operation_type: str) -> Dict:
+    max_timeout_retries = 5
+    timeout_retries = 0
     while True:
         if operation_type == "compute.zone_operation":
             op_ret = await hub.exec.gcp_api.client.compute.zone_operation.wait(
@@ -93,14 +95,17 @@ async def wait_for_operation(hub, ctx, operation, operation_type: str) -> Dict:
             )
 
         if not op_ret or not op_ret["ret"] or not op_ret["result"]:
-            # wait() call timed out?
-            break
+            if timeout_retries < max_timeout_retries:
+                timeout_retries += 1
+                continue
+            else:
+                break
 
         operation = op_ret["ret"]
         if operation["status"] == "DONE" or "error" in operation:
             break
 
-        time.sleep(1)
+        await asyncio.sleep(1)
 
     return operation
 
@@ -125,7 +130,7 @@ async def await_operation_completion(
         result["comment"] += api_call_ret["comment"]
         return result
 
-    if "compute#operation" in api_call_ret["ret"].get("kind"):
+    if hub.tool.gcp.operation_utils.is_operation(api_call_ret["ret"]):
         operation = api_call_ret["ret"]
 
         operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
@@ -141,3 +146,9 @@ async def await_operation_completion(
 
     result["result"] = True
     return result
+
+
+def is_operation(hub, candidate) -> bool:
+    return (
+        candidate and "kind" in candidate and candidate["kind"].endswith("#operation")
+    )
