@@ -56,7 +56,7 @@ def resolve_sub(hub, ref: str, gcp_api):
         _GCP_SUB_CACHE[ref] = cm
         return cm
 
-    return _GCP_SUB_CACHE.get(ref, gen_sub(ref, gcp_api))
+    return _GCP_SUB_CACHE.get(ref) or gen_sub(ref, gcp_api)
 
 
 class ContractMod(LoadedMod):
@@ -131,15 +131,21 @@ class ContractMod(LoadedMod):
         if present_params.get("user_project") == "None":
             present_params["user_project"] = None
 
-        exclude_keys_from_transformation = None
+        exclude_keys_from_transformation = []
         if present_params.get("body", False):
             exclude_keys_from_transformation = self._hub.tool.gcp.resource_prop_utils.get_exclude_keys_from_transformation(
-                present_params["body"], self._resource_type
+                present_params["body"], self._resource_type, is_raw_resource=False
             )
 
+        manual_mappings = self._hub.tool.gcp.resource_prop_utils.get_manual_mappings(
+            self._resource_type
+        )
         raw_params = (
             self._hub.tool.gcp.conversion_utils.convert_present_resource_to_raw(
-                present_params, self._resource_type, exclude_keys_from_transformation
+                present_params,
+                self._resource_type,
+                exclude_keys_from_transformation,
+                manual_mappings,
             )
         )
 
@@ -157,6 +163,9 @@ class ContractMod(LoadedMod):
                 result["result"] = False
                 return result
 
+            if not response:
+                return result
+
             if "#operation" in response.get("kind", ""):
                 result["ret"] = response
                 return result
@@ -231,6 +240,11 @@ def process_response(hub, response: Dict, resource_type: str, method_name: str)
         response, resource_type, method_name
     )
     if singular_result_expected:
+        if method_name == "get":
+            hub.tool.gcp.resource_prop_utils.populate_resource_with_assumed_values(
+                response, resource_type
+            )
+
         resource_id = hub.tool.gcp.resource_prop_utils.extract_resource_id(
             response, resource_type
         )
@@ -245,6 +259,10 @@ def process_response(hub, response: Dict, resource_type: str, method_name: str)
         # Multiple entries in call result, e.g. after list() call
         ret_items = []
         for service_resource in response.get("items") or {}:
+            hub.tool.gcp.resource_prop_utils.populate_resource_with_assumed_values(
+                service_resource, resource_type
+            )
+
             resource_id = hub.tool.gcp.resource_prop_utils.extract_resource_id(
                 service_resource, resource_type
             )
@@ -278,7 +296,9 @@ def filter_raw_properties_to_present(
     filtered = hub.tool.gcp.resource_prop_utils.format_path_params(
         filtered, resource_type
     )
-    return hub.tool.gcp.conversion_utils.convert_raw_resource_to_present(filtered)
+    return hub.tool.gcp.conversion_utils.convert_raw_resource_to_present(
+        filtered, resource_type
+    )
 
 
 def convert_dict_items_to_list(hub, dict_items: Dict, resource_type: str) -> list:
