@@ -196,7 +196,10 @@ def is_pending(hub, ret: dict, state: str = None, **pending_kwargs) -> bool:
 
 
 def compare_states(
-    hub, old_state: Dict, plan_state: Dict, resource_type: str = None
+    hub,
+    old_state: Dict,
+    plan_state: Dict,
+    resource_type: str = None,
 ) -> Dict:
     exclude_paths = []
 
@@ -205,35 +208,89 @@ def compare_states(
             exclude_paths.append(f"root['{key}']")
 
     if resource_type:
-        paths = hub.tool.gcp.resource_prop_utils.get_exclude_paths(resource_type)
-        for path in paths:
-            s = "root"
-            for part in path.split("."):
-                if part.endswith("[]"):
-                    s += f"\\['{part[:-2]}'\\]\\[\\d+\\]"
-                else:
-                    s += f"\\['{part}'\\]"
-            exclude_paths.append(s)
+        exclude_paths.extend(
+            hub.tool.gcp.utils.get_deep_diff_exclude_paths(resource_type)
+        )
 
     changes = DeepDiff(old_state, plan_state, exclude_regex_paths=exclude_paths)
 
+    hub.tool.gcp.utils.filter_diff(changes, plan_state)
     # If an item is in old_state but not in plan_state, i.e. changes.get("dictionary_item_removed") is not None,
     # we can ignore this change
 
     # TODO: changes.get("dictionary_item_removed") also includes nested items, which means deleted nested items
     #  are ignored. Ignore only root items and read-only nested items
-    if (
-        not changes.get("dictionary_item_added")
-        and not changes.get("iterable_item_added")
-        and not changes.get("iterable_item_removed")
-        and not changes.get("values_changed")
-    ):
+    # type_changes can occur when a value was previously None (NoneType) and then a value was specified
+    relevant_changes = (
+        set(changes.get("dictionary_item_added") or set())
+        | set(changes.get("iterable_item_added") or set())
+        | set(changes.get("iterable_item_removed") or set())
+        | set(changes.get("values_changed") or set())
+        | set(changes.get("type_changes") or set())
+    )
+
+    if not relevant_changes:
         return {}
 
+    changes["relevant_changes"] = relevant_changes
     return changes
 
 
-def get_project_from_account(ctx: dict, project: str) -> str:
+def get_plan_state_value_from_deep_diff_path(hub, deep_diff_path: str, plan_state):
+    result = plan_state
+    # remove root prefix
+    deep_diff_path = deep_diff_path[4:]
+    while deep_diff_path:
+        if deep_diff_path.startswith("['"):
+            deep_diff_path = deep_diff_path[2:]
+            end_index = deep_diff_path.find("']")
+            path_segment = deep_diff_path[:end_index]
+            result = result.get(path_segment)
+            deep_diff_path = deep_diff_path[end_index + 2 :]
+        elif deep_diff_path.startswith("["):
+            #
+            deep_diff_path = deep_diff_path[1:]
+            end_index = deep_diff_path.find("]")
+            index_string = deep_diff_path[:end_index]
+            if index_string.isdecimal():
+                index = int(index_string)
+                result = result[index] if index < len(result) else None
+            deep_diff_path = deep_diff_path[end_index + 1 :]
+        if not result:
+            return result
+
+    return result
+
+
+def get_deep_diff_exclude_paths(hub, resource_type: str):
+    exclude_paths = []
+    paths = hub.tool.gcp.resource_prop_utils.get_exclude_paths(resource_type)
+    for path in paths:
+        s = "root"
+        for part in path.split("."):
+            if part.endswith("[]"):
+                s += f"\\['{part[:-2]}'\\]\\[\\d+\\]"
+            else:
+                s += f"\\['{part}'\\]"
+        exclude_paths.append(s)
+    return exclude_paths
+
+
+def filter_diff(hub, changes, plan_state):
+    # filter out added empty list values - assume they're the default ones
+    added_items = changes.get("dictionary_item_added")
+    if added_items:
+        filtered_added_items = copy.copy(added_items)
+        for added_item in added_items:
+            value = hub.tool.gcp.utils.get_plan_state_value_from_deep_diff_path(
+                added_item, plan_state
+            )
+            if value == []:
+                filtered_added_items.remove(added_item)
+        changes["dictionary_item_added"] = filtered_added_items
+
+
+def get_project_from_account(hub, ctx: dict, project: str) -> str:
     """If project is explicitly passed by the user, this project will be returned.
     If project is empty, this method will return gcp account default project
     :param ctx: A dict with the keys/values for the execution of the Idem run
@@ -242,7 +299,9 @@ def get_project_from_account(ctx: dict, project: str) -> str:
     :return: the correct project
     """
     if not project:
-        project = ctx.acct.project_id
+        project = ctx.get("acct", {}).get("project_id")
+    if not project:
+        hub.log.warning("Could not find project info from account")
     return project
 
 
